@@ -1,3 +1,3 @@
 from .meta import __progname__, __version__, __description__
-from .app import flask_app, set_working_directory
+from .app import flask_app, set_config, update_config
 from . import cli
\ No newline at end of file
